@@ -1,5 +1,7 @@
 """pydocstyle support."""
 
+from argparse import ArgumentParser
+
 from pydocstyle import ConventionChecker as PyDocChecker
 from pydocstyle.violations import conventions
 
@@ -12,9 +14,21 @@ class Linter(Abstract):
 
     name = "pydocstyle"
 
+    @classmethod
+    def add_args(cls, parser: ArgumentParser):
+        """Add --max-complexity option."""
+        parser.add_argument(
+            "--pydocstyle-convention",
+            choices=list(conventions.keys()),
+            help="choose the basic list of checked errors by specifying an existing convention.",
+        )
+
     def run_check(self, ctx: RunContext):  # noqa
         """Check code with pydocstyle."""
         params = ctx.get_params("pydocstyle")
+        options = ctx.options
+        if options and options.pydocstyle_convention:
+            params.setdefault('convention', options.pydocstyle_convention)
         convention_codes = conventions.get(params.get("convention"))
         for err in PyDocChecker().check_source(
             ctx.source,
