@@ -1,9 +1,11 @@
 """Pylint integration to Pylama."""
 import logging
+from argparse import ArgumentParser
 from os import environ
 from pathlib import Path
 from typing import Dict
 
+from pylint.interfaces import CONFIDENCE_LEVELS
 from pylint.lint import Run
 from pylint.reporters import BaseReporter
 
@@ -21,10 +23,26 @@ class Linter(BaseLinter):
 
     name = "pylint"
 
+    @classmethod
+    def add_args(cls, parser: ArgumentParser):
+        """Add --max-complexity option."""
+        parser.add_argument(
+            "--pylint-confidence",
+            choices=[cc.name for cc in CONFIDENCE_LEVELS],
+            help="Only show warnings with the listed confidence levels.",
+        )
+
     def run_check(self, ctx: RunContext):
         """Pylint code checking."""
         logger.debug("Start pylint")
         params = ctx.get_params("pylint")
+        options = ctx.options
+        if options:
+            params.setdefault("max_line_length", options.max_line_length)
+            params.setdefault("confidence", options.pylint_confidence)
+
+        params['enable'] = ctx.select | ctx.get_filter('pylint', 'select')
+        params['disable'] = ctx.ignore | ctx.get_filter('pylint', 'ignore')
 
         class Reporter(BaseReporter):
             """Handle messages."""
@@ -35,6 +53,7 @@ class Linter(BaseLinter):
             def handle_message(self, msg):
                 msg_id = msg.msg_id
                 ctx.push(
+                    filtrate=False,
                     col=msg.column + 1,
                     lnum=msg.line,
                     number=msg_id,
@@ -47,7 +66,8 @@ class Linter(BaseLinter):
         logger.debug(params)
 
         reporter = Reporter()
-        Run([ctx.temp_filename] + params.to_attrs(), reporter=reporter, exit=False)
+        args = params.to_attrs()
+        Run([ctx.temp_filename] + args, reporter=reporter, exit=False)
 
 
 class _Params:
@@ -56,8 +76,7 @@ class _Params:
     def __init__(self, params: Dict):
         attrs = {
             name.replace("_", "-"): self.prepare_value(value)
-            for name, value in params.items()
-            if value is not None
+            for name, value in params.items() if value
         }
         if HOME_RCFILE.exists():
             attrs["rcfile"] = HOME_RCFILE.as_posix()
